import React, { useState } from 'react'
import { Layout } from 'antd'
import { DataTable } from './Components/DataTable/DataTable'
import { TData } from './types/dataSource'
import { Form } from './Components/Form/Form'
import { v4 as uuidv4 } from 'uuid';

const LayoutStyle: React.CSSProperties = {
  background: "#444444",
  height: "100vh",
  width: "100vw"
}

function App() {
  const [data, setData] = useState<TData[]>([]);
  const [inputData, setInputData] = useState({
    title: "",
    price: 0,
    stock: 0
  })

  const onClickHandler = () => {
    setData(prevState => ([...prevState, {...inputData, key: uuidv4()}]));
    setInputData({title: "", price: 0, stock: 0});
  };

  const onChangeHandler = (e: React.ChangeEvent<HTMLInputElement>) => {
    const {name, value} = e.target;
    setInputData(prevState => ({...prevState, [name]: value}));
  };

  const onDeleteHandler = (key: string) => {
    const dataCopy = [...data];
    const index = dataCopy.findIndex(item => item.key === key);
    dataCopy.splice(0, index);
    setData(dataCopy);
  };

  return (
    <Layout style={LayoutStyle}>
      <DataTable 
        data={data}
      />
      <Form 
        inputData={inputData} 
        onChange={onChangeHandler} 
        onClick={onClickHandler}
      />
    </Layout>
  )
}

export default App
